package java.awt;

import java.awt.event.KeyEvent;
import java.io.Serializable;

public class MenuShortcut implements Serializable
{
    int key;
    boolean usesShift;
    private static final long serialVersionUID = 143448358473180225L;
    
    public MenuShortcut(int n) {
        this(n, false);
    }
    
    public MenuShortcut(int key, boolean usesShift) {
        this.key = key;
        this.usesShift = usesShift;
    }
    
    public int getKey() {
        return this.key;
    }
    
    public boolean usesShiftModifier() {
        return this.usesShift;
    }
    
    public boolean equals(MenuShortcut menuShortcut) {
        return menuShortcut != null && menuShortcut.getKey() == this.key && menuShortcut.usesShiftModifier() == this.usesShift;
    }
    
    @Override
    public boolean equals(Object o) {
        return o instanceof MenuShortcut && this.equals((MenuShortcut)o);
    }
    
    @Override
    public int hashCode() {
        return this.usesShift ? (~this.key) : this.key;
    }
    
    @Override
    public String toString() {
        int menuShortcutKeyMask = 0;
        if (!GraphicsEnvironment.isHeadless()) {
            menuShortcutKeyMask = Toolkit.getDefaultToolkit().getMenuShortcutKeyMask();
        }
        if (this.usesShiftModifier()) {
            menuShortcutKeyMask |= 0x1;
        }
        return KeyEvent.getKeyModifiersText(menuShortcutKeyMask) + "+" + KeyEvent.getKeyText(this.key);
    }
    
    protected String paramString() {
        String str = "key=" + this.key;
        if (this.usesShiftModifier()) {
            str += ",usesShiftModifier";
            return str;
        }
        return str;
    }
}
